==> symfony_6.4.18+dfsg.orig.tar.xz: symfony-6.4.18/src/Symfony/Component/Intl/Resources/data/scripts/ga.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Aghb' => 'Albánach Cugasach',
        'Arab' => 'Arabach',
        'Aran' => 'Nastaliq',
        'Armi' => 'Aramach Impiriúil',
        'Armn' => 'Airméanach',
        'Avst' => 'Aivéisteach',
        'Bali' => 'Bailíoch',
        'Bamu' => 'Bamum',
        'Bass' => 'Bassa Vah',
        'Batk' => 'Batacach',
        'Beng' => 'Beangálach',
        'Bhks' => 'Bhaiksuki',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brámais',
        'Brai' => 'Braille',
        'Bugi' => 'Buigineach',
        'Buhd' => 'Buthaideach',
        'Cakm' => 'Seácmais',
        'Cans' => 'Siollach Bundúchasach Ceanadach Aontaithe',
        'Cari' => 'Cló Cairiach',
        'Cher' => 'Seiricíoch',
        'Copt' => 'Coptach',
        'Cprt' => 'Cipireach',
        'Cyrl' => 'Coireallach',
        'Deva' => 'Déiveanágrach',
        'Dsrt' => 'Deseret',
        'Dupl' => 'Gearrscríobh Duployan',
        'Egyd' => 'Éigipteach coiteann',
        'Egyh' => 'Éigipteach cliarúil',
        'Egyp' => 'Iairiglifí Éigipteacha',
        'Elba' => 'Elbasan',
        'Ethi' => 'Aetóipic',
        'Geor' => 'Seoirseach',
        'Glag' => 'Glagalach',
        'Gonm' => 'Masaram Gondi',
        'Goth' => 'Gotach',
        'Gran' => 'Grantha',
        'Grek' => 'Gréagach',
        'Gujr' => 'Gúisearátach',
        'Guru' => 'Gurmúcach',
        'Hanb' => 'Han agus Bopomofo',
        'Hang' => 'Hangalach',
        'Hani' => 'Han',
        'Hano' => 'Hananúis',
        'Hans' => 'Simplithe',
        'Hant' => 'Traidisiúnta',
        'Hatr' => 'Hatran',
        'Hebr' => 'Eabhrach',
        'Hira' => 'Hireagánach',
        'Hluw' => 'Iairiglifí Anatólacha',
        'Hmng' => 'Pahawh Hmong',
        'Hrkt' => 'Siollabraí Seapánacha',
        'Hung' => 'Sean-Ungárach',
        'Ital' => 'Sean-Iodáilic',
        'Jamo' => 'Seamó',
        'Java' => 'Iávach',
        'Jpan' => 'Seapánach',
        'Kali' => 'Kayah Li',
        'Kana' => 'Catacánach',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Ciméarach',
        'Khoj' => 'Khojki',
        'Knda' => 'Cannadach',
        'Kore' => 'Cóiréach',
        'Kthi' => 'Kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Laosach',
        'Latg' => 'Cló Gaelach',
        'Latn' => 'Laidineach',
        'Lepc' => 'Lepcha',
        'Limb' => 'Liombúch',
        'Lina' => 'Líneach A',
        'Linb' => 'Líneach B',
        'Lisu' => 'Fraser',
        'Lyci' => 'Liciach',
        'Lydi' => 'Lidiach',
        'Mahj' => 'Mahasánach',
        'Mand' => 'Mandaean',
        'Mani' => 'Mainicéasach',
        'Marc' => 'Marchen',
        'Maya' => 'Iairiglifí Máigheacha',
        'Mend' => 'Meindeach',
        'Merc' => 'Meroitic Cursive',
        'Mero' => 'Meroitic',
        'Mlym' => 'Mailéalamach',
        'Mong' => 'Mongólach',
        'Mroo' => 'Mro',
        'Mtei' => 'Meitei Mayek',
        'Mult' => 'Multani',
        'Mymr' => 'Maenmarach',
        'Narb' => 'Sean-Arabach Thuaidh',
        'Nbat' => 'Nabataean',
        'Nkoo' => 'N-cóis',
        'Nshu' => 'Nüshu',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Chiki',
        'Orkh' => 'Orkhon',
        'Orya' => 'Oiríseach',
        'Osge' => 'Ósáis',
        'Osma' => 'Osmanya',
        'Palm' => 'Palmyrene',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'Sean-Pheirmeach',
        'Phag' => 'Phags-pa',
        'Phli' => 'Pachlavais Inscríbhinne',
        'Phlp' => 'Pachlavais Saltrach',
        'Phnx' => 'Féiníceach',
        'Plrd' => 'Pollard Foghrach',
        'Prti' => 'Pairtiach Inscríbhinniúil',
        'Rjng' => 'Rejang',
        'Rohg' => 'Hanifi',
        'Runr' => 'Rúnach',
        'Samr' => 'Samárach',
        'Sarb' => 'Sean-Arabach Theas',
        'Saur' => 'Saurashtra',
        'Sgnw' => 'Litritheoireacht Comharthaí',
        'Shaw' => 'Shawach',
        'Shrd' => 'Sharada',
        'Sidd' => 'Siddham',
        'Sind' => 'Khudawadi',
        'Sinh' => 'Siolónach',
        'Sora' => 'Sora Sompeng',
        'Soyo' => 'Soyombo',
        'Sund' => 'Sundainéis',
        'Sylo' => 'Syloti Nagri',
        'Syrc' => 'Siriceach',
        'Tagb' => 'Tagbanwa',
        'Takr' => 'Takri',
        'Tale' => 'Deiheoingis',
        'Talu' => 'Tai Lue Nua',
        'Taml' => 'Tamalach',
        'Tang' => 'Tangut',
        'Tavt' => 'Tai Viet',
        'Telu' => 'Teileagúch',
        'Tfng' => 'Tifinagh',
        'Tglg' => 'Tagálagach',
        'Thaa' => 'Tánach',
        'Thai' => 'Téalannach',
        'Tibt' => 'Tibéadach',
        'Tirh' => 'Tirhuta',
        'Ugar' => 'Úgairíteach',
        'Vaii' => 'Vadhais',
        'Wara' => 'Varang Kshiti',
        'Xpeo' => 'Sean-Pheirseach',
        'Xsux' => 'Dingchruthach Suiméar-Acádach',
        'Yiii' => 'Ís',
        'Zanb' => 'Zanabazar Square',
        'Zinh' => 'Oidhreacht',
        'Zmth' => 'Nodaireacht Mhatamaiticiúil',
        'Zsye' => 'Emoji',
        'Zsym' => 'Siombailí',
        'Zxxx' => 'Neamhscríofa',
        'Zyyy' => 'Coitianta',
    ],
];

==> symfony_7.4.2+dfsg.orig.tar.xz: symfony-7.4.2/src/Symfony/Component/Intl/Resources/data/scripts/ga.php <==
<?php

return [
    'Names' => [
        'Adlm' => 'Adlam',
        'Aghb' => 'Albánach Cugasach',
        'Arab' => 'Arabach',
        'Aran' => 'Nastaliq',
        'Armi' => 'Aramach Impiriúil',
        'Armn' => 'Airméanach',
        'Avst' => 'Aivéisteach',
        'Bali' => 'Bailíoch',
        'Bamu' => 'Bamum',
        'Bass' => 'Bassa Vah',
        'Batk' => 'Batacach',
        'Beng' => 'Beangálach',
        'Bhks' => 'Bhaiksuki',
        'Bopo' => 'Bopomofo',
        'Brah' => 'Brámais',
        'Brai' => 'Braille',
        'Bugi' => 'Buigineach',
        'Buhd' => 'Buthaideach',
        'Cakm' => 'Seácmais',
        'Cans' => 'Siollach Bundúchasach Ceanadach Aontaithe',
        'Cari' => 'Cló Cairiach',
        'Cher' => 'Seiricíoch',
        'Copt' => 'Coptach',
        'Cprt' => 'Cipireach',
        'Cyrl' => 'Coireallach',
        'Deva' => 'Déiveanágrach',
        'Dsrt' => 'Deseret',
        'Dupl' => 'Gearrscríobh Duployan',
        'Egyd' => 'Éigipteach coiteann',
        'Egyh' => 'Éigipteach cliarúil',
        'Egyp' => 'Iairiglifí Éigipteacha',
        'Elba' => 'Elbasan',
        'Ethi' => 'Aetóipice',
        'Geor' => 'Seoirseach',
        'Glag' => 'Glagalach',
        'Gonm' => 'Masaram Gondi',
        'Goth' => 'Gotach',
        'Gran' => 'Grantha',
        'Grek' => 'Gréagach',
        'Gujr' => 'Gúisearátach',
        'Guru' => 'Gurmúcach',
        'Hanb' => 'Han agus Bopomofo',
        'Hang' => 'Hangalach',
        'Hani' => 'Han',
        'Hano' => 'Hananúis',
        'Hans' => 'Simplithe',
        'Hant' => 'Traidisiúnta',
        'Hatr' => 'Hatran',
        'Hebr' => 'Eabhrach',
        'Hira' => 'Hireagánach',
        'Hluw' => 'Iairiglifí Anatólacha',
        'Hmng' => 'Pahawh Hmong',
        'Hrkt' => 'Siollabraí Seapánacha',
        'Hung' => 'Sean-Ungárach',
        'Ital' => 'Sean-Iodáilic',
        'Jamo' => 'Seamó',
        'Java' => 'Iávach',
        'Jpan' => 'Seapánach',
        'Kali' => 'Kayah Li',
        'Kana' => 'Catacánach',
        'Khar' => 'Kharoshthi',
        'Khmr' => 'Ciméarach',
        'Khoj' => 'Khojki',
        'Knda' => 'Cannadach',
        'Kore' => 'Cóiréach',
        'Kthi' => 'Kaithi',
        'Lana' => 'Lanna',
        'Laoo' => 'Laosach',
        'Latg' => 'Cló Gaelach',
        'Latn' => 'Laidineach',
        'Lepc' => 'Lepcha',
        'Limb' => 'Liombúch',
        'Lina' => 'Líneach A',
        'Linb' => 'Líneach B',
        'Lisu' => 'Fraser',
        'Lyci' => 'Liciach',
        'Lydi' => 'Lidiach',
        'Mahj' => 'Mahasánach',
        'Mand' => 'Mandaean',
        'Mani' => 'Mainicéasach',
        'Marc' => 'Marchen',
        'Maya' => 'Iairiglifí Máigheacha',
        'Mend' => 'Meindeach',
        'Merc' => 'Meroitic Cursive',
        'Mero' => 'Meroitic',
        'Mlym' => 'Mailéalamach',
        'Mong' => 'Mongólach',
        'Mroo' => 'Mro',
        'Mtei' => 'Meitei Mayek',
        'Mult' => 'Multani',
        'Mymr' => 'Maenmarach',
        'Narb' => 'Sean-Arabach Thuaidh',
        'Nbat' => 'Nabataean',
        'Nkoo' => 'N-cóis',
        'Nshu' => 'Nüshu',
        'Ogam' => 'Ogham',
        'Olck' => 'Ol Chiki',
        'Orkh' => 'Orkhon',
        'Orya' => 'Oiríseach',
        'Osge' => 'Ósáis',
        'Osma' => 'Osmanya',
        'Palm' => 'Palmyrene',
        'Pauc' => 'Pau Cin Hau',
        'Perm' => 'Sean-Pheirmeach',
        'Phag' => 'Phags-pa',
        'Phli' => 'Pachlavais Inscríbhinne',
        'Phlp' => 'Pachlavais Saltrach',
        'Phnx' => 'Féiníceach',
        'Plrd' => 'Pollard Foghrach',
        'Prti' => 'Pairtiach Inscríbhinniúil',
        'Rjng' => 'Rejang',
        'Rohg' => 'Hanifi',
        'Runr' => 'Rúnach',
        'Samr' => 'Samárach',
        'Sarb' => 'Sean-Arabach Theas',
        'Saur' => 'Saurashtra',
        'Sgnw' => 'Litritheoireacht Comharthaí',
        'Shaw' => 'Shawach',
        'Shrd' => 'Sharada',
        'Sidd' => 'Siddham',
        'Sind' => 'Khudawadi',
        'Sinh' => 'Siolónach',
        'Sora' => 'Sora Sompeng',
        'Soyo' => 'Soyombo',
        'Sund' => 'Sundainéis',
        'Sylo' => 'Syloti Nagri',
        'Syrc' => 'Siriceach',
        'Tagb' => 'Tagbanwa',
        'Takr' => 'Takri',
        'Tale' => 'Deiheoingis',
        'Talu' => 'Tai Lue Nua',
        'Taml' => 'Tamalach',
        'Tang' => 'Tangut',
        'Tavt' => 'Tai Viet',
        'Telu' => 'Teileagúch',
        'Tfng' => 'Tifinagh',
        'Tglg' => 'Tagálagach',
        'Thaa' => 'Tánach',
        'Thai' => 'Téalannach',
        'Tibt' => 'Tibéadach',
        'Tirh' => 'Tirhuta',
        'Ugar' => 'Úgairíteach',
        'Vaii' => 'Vadhais',
        'Wara' => 'Varang Kshiti',
        'Xpeo' => 'Sean-Pheirseach',
        'Xsux' => 'Dingchruthach Suiméar-Acádach',
        'Yiii' => 'Ís',
        'Zanb' => 'Zanabazar Square',
        'Zinh' => 'Oidhreacht',
        'Zmth' => 'Nodaireacht Mhatamaiticiúil',
        'Zsye' => 'Emoji',
        'Zsym' => 'Siombailí',
        'Zxxx' => 'Neamhscríofa',
        'Zyyy' => 'Coitianta',
    ],
];
